frozen
=================================================

.. module:: smisk.util.frozen
.. versionadded:: 1.1.0

Immutable types

.. class:: smisk.util.frozen.frozendict(dict)

  Immutable dictionary.

  .. method:: clear(*args, **kwargs)

  .. method:: copy()

    D.copy() -> a shallow copy of D

  .. method:: pop(*args, **kwargs)

  .. method:: popitem(*args, **kwargs)

  .. method:: setdefault(*args, **kwargs)

  .. method:: update(*args)

    Update a mutable copy with key/value pairs from b, replacing existing keys.

    :returns: A mutable copy with updated pairs.
    :rtype: dict

